<div class="form_group">
    <?php if (!empty($rule['label'])) : ?>
        <label for="<?= $data['id'] ?>"><?= $rule['label'] . ((in_array('required', $rule['rules'])) ? ' *' : '') ?></label>
    <?php endif; ?>
    <?php if (!empty($rule['type']) && $rule['type'] == 'textarea') : ?>
        <?= form_textarea($data) ?>
    <?php else : ?>
        <?= form_input($data) ?>
    <?php endif; ?>
    <?= form_error($data['name']) ?>
</div>